==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/mag_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "mag_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="560" valign="top">
			<?php
			if (isset($blog)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $blog['blog_create_datetime'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $blog['blog_title'];?><br />
						</span>
						<?php echo $blog['blog_body_display'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_author'];?>: <a href="sn_profile.php?user_id=<?php echo $author['user_id'];?>&amp;user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_hometown'];?>: <?php echo $author['profile_hometown'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>
			
			<?php
			if (isset($subject)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $subject['subject_create_datetime'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php
						if (isset($subject['image'])) {
						?>
						<img src="get_file.php?file=<?php echo $subject['image']['file'];?>" border="0" align="left" class="picture_left" title="<?php echo $subject['image']['file_title'];?>">
						<?php  }?>
						<span class="txt_item_title">
						<?php echo $subject['subject_title'];?><br />
						</span>
						<?php echo $subject['display_subject_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_last_edit'];?>: <a href="sn_profile.php?user_id=<?php echo $author['user_id'];?>&amp;user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_hometown'];?>: <?php echo $author['profile_hometown'];?><br />
					</td>
			    </tr>
			</table>
			<?php }?>
			
			
			<?php
			if (isset($poll)) {
 			?>
 			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<tr>
 					<td class="txt_title" align="right" colspan="2">
 						<?php echo $lang['section_poll'];?><br />
 						<hr />
 					</td>
 				</tr>
					<tr>
						<td class="picture" valign="top">
							<?php
							include $templatePath . "poll_detail.inc.tpl.php";
							?>
						</td>
						<td valign="top" width="30%" class="picture">
							<table width="100%" cellpadding="4" cellspacing="0" border="0">
								<tr>
									<td valign="top">
										<b><?php echo $lang['hdr_vote_history'];?></b><br />
									</td>
								</tr>
								<?php
								if (isset($poll_history)) {
								foreach($poll_history as $key => $i):
								?>
								<tr>
									<td valign="top" class="txt_footer">
										<?php echo $i['answer_create_datetime'];?><br />
										<?php echo $i['option_body'];?><br />
									</td>
								</tr>
								<?php
								endforeach;
								}
								?>
							</table>
						</td>
				    </tr>
 			</table>
			<?php }?>
			
			<?php
			if (isset($library)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $library['library_create_datetime'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $library['library_title'];?><br />
						</span>
						<?php echo $library['library_body'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_last_edit'];?>: <a href="sn_profile.php?user_id=<?php echo $author['user_id'];?>&amp;user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_hometown'];?>: <?php echo $author['profile_hometown'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					
			<form action="mag_item.php" method="post">
			
			<?php
			if (isset($blog)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $blog['blog_id'];?>" />
			<input type="hidden" name="blog_id" value="<?php echo $blog['blog_id'];?>" />
			<input type="hidden" name="section_id" value="<?php echo $blog['section_id'];?>" />
			<?php }?>
			
			<?php
			if (isset($subject)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $subject['subject_id'];?>" />
			<input type="hidden" name="subject_id" value="<?php echo $subject['subject_id'];?>" />
			<?php }?>
			
			<?php
			if (isset($library)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $library['library_id'];?>" />
			<input type="hidden" name="library_id" value="<?php echo $library['library_id'];?>" />
			<input type="hidden" name="section_id" value="<?php echo $library['section_id'];?>" />
			<?php }?>
			
			<?php
			if (isset($poll)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $poll['poll_id'];?>" />
			<input type="hidden" name="poll_id" value="<?php echo $poll['poll_id'];?>" />
			<input type="hidden" name="section_id" value="<?php echo $poll['section_id'];?>" />
			<?php }?>

			<table width="100%" cellpadding="0" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_comments'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($comments)) {
				foreach($comments as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="0" border="0">
							<tr>
								<td class="txt_footer" colspan="2">
									<?php echo $lang['txt_from'];?>: <a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>" class="txt_footer_link"><?php echo $i['profile_nic'];?></a>&nbsp;(<?php echo $lang['txt_joined'];?>: <?php echo $i['profile_create_datetime'];?>, <?php echo $lang['txt_hometown'];?>: <?php echo $i['profile_hometown'];?>)<br />
									<?php echo $lang['txt_comment_datetime'];?>: <?php echo $i['comment_create_datetime'];?><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<?php echo $i['comment_body'];?><br />
								</td>
								<td valign="top" align="right">
									<?php
									if (isset($poll) && !isset($poll['poll_anon'])) {
									?>
									<table cellpadding="2" cellspacing="0" border="0">
										<tr>
											<td valign="top" colspan="2">
												<?php echo $lang['hdr_vote_history'];?><br />
											</td>
										</tr>
										<?php
										if (isset($i['vote'])) {
										foreach($i['vote'] as $key => $r):
										?>
										<tr>
											<td valign="top" class="txt_footer">
												<?php echo $r['answer_create_datetime'];?><br />
											</td>
											<td valign="top" class="txt_footer">
												<?php echo $r['option_body'];?><br />
											</td>
										</tr>
										<?php
										endforeach;
										}
										?>
									</table>
									<?php
									}
									?>
								</td>
						    </tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_comments'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<?php
			if (isset($allow_add_comment)) {
			?>
			<input type="hidden" name="data[comment_body]" value="<?php if (isset($comment['comment_body'])) { echo $comment['comment_body'];}?>" />
						
			<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="20"><br />
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($display) && $display == "preview_comment") {
				?>
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_comment_preview'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $comment['display_comment_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="edit_again" class="formInput" value="<?php echo $lang['sub_edit_again'];?>" />&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_save'];?>" /><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>

				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_comment_help'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name="data[comment_body]" rows="5" cols="70" class="formInput"><?php if(isset($comment['comment_body'])) { echo $comment['comment_body'];}?></textarea><br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="preview" class="formInput" value="<?php echo $lang['sub_preview'];?>">&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_add'];?>"><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
			<?php
			}
			else {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_no_comment_allowed'];?><br />
					</td>
				</tr>
			</table>
			<?php
			}
			?>
			</form>
		</td>
	</tr>
</table>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/mag_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "mag_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="560" valign="top">
			<?php
			if (isset($blog)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $blog['blog_create_datetime'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $blog['blog_title'];?><br />
						</span>
						<?php echo $blog['blog_body_display'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_author'];?>: <a href="sn_profile.php?user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_hometown'];?>: <?php echo $author['profile_hometown'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>
			
			<?php
			if (isset($subject)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $subject['subject_create_datetime'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php
						if (isset($subject['image'])) {
						?>
						<img src="get_file.php?file=<?php echo $subject['image']['file'];?>" border="0" align="left" class="picture_left" title="<?php echo $subject['image']['file_title'];?>">
						<?php  }?>
						<span class="txt_item_title">
						<?php echo $subject['subject_title'];?><br />
						</span>
						<?php echo $subject['display_subject_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_last_edit'];?>: <a href="sn_profile.php?user_id=<?php echo $author['user_id'];?>&amp;user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_hometown'];?>: <?php echo $author['profile_hometown'];?><br />
					</td>
			    </tr>
			</table>
			<?php }?>
			
			
			<?php
			if (isset($poll)) {
 			?>
 			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<tr>
 					<td class="txt_title" align="right" colspan="2">
 						<?php echo $lang['section_poll'];?><br />
 						<hr />
 					</td>
 				</tr>
					<tr>
						<td class="picture" valign="top">
							<?php
							include $templatePath . "poll_detail.inc.tpl.php";
							?>
						</td>
						<td valign="top" width="30%" class="picture">
							<table width="100%" cellpadding="4" cellspacing="0" border="0">
								<tr>
									<td valign="top">
										<b><?php echo $lang['hdr_vote_history'];?></b><br />
									</td>
								</tr>
								<?php
								if (isset($poll_history)) {
								foreach($poll_history as $key => $i):
								?>
								<tr>
									<td valign="top" class="txt_footer">
										<?php echo $i['answer_create_datetime'];?><br />
										<?php echo $i['option_body'];?><br />
									</td>
								</tr>
								<?php
								endforeach;
								}
								?>
							</table>
						</td>
				    </tr>
 			</table>
			<?php }?>
			
			<?php
			if (isset($library)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $library['library_create_datetime'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $library['library_title'];?><br />
						</span>
						<?php echo $library['library_body'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_last_edit'];?>: <a href="sn_profile.php?user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_hometown'];?>: <?php echo $author['profile_hometown'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					
			<form action="mag_item.php" method="post">
			
			<?php
			if (isset($blog)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $blog['blog_id'];?>" />
			<input type="hidden" name="blog_id" value="<?php echo $blog['blog_id'];?>" />
			<input type="hidden" name="section_id" value="<?php echo $blog['section_id'];?>" />
			<?php }?>
			
			<?php
			if (isset($subject)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $subject['subject_id'];?>" />
			<input type="hidden" name="subject_id" value="<?php echo $subject['subject_id'];?>" />
			<?php }?>
			
			<?php
			if (isset($library)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $library['library_id'];?>" />
			<input type="hidden" name="library_id" value="<?php echo $library['library_id'];?>" />
			<input type="hidden" name="section_id" value="<?php echo $library['section_id'];?>" />
			<?php }?>
			
			<?php
			if (isset($poll)) {
			?>
			<input type="hidden" name="comment_item_id" value="<?php echo $poll['poll_id'];?>" />
			<input type="hidden" name="poll_id" value="<?php echo $poll['poll_id'];?>" />
			<input type="hidden" name="section_id" value="<?php echo $poll['section_id'];?>" />
			<?php }?>

			<table width="100%" cellpadding="0" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_comments'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($comments)) {
				foreach($comments as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="0" border="0">
							<tr>
								<td class="txt_footer" colspan="2">
									<?php echo $lang['txt_from'];?>: <a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>" class="txt_footer_link"><?php echo $i['profile_nic'];?></a>&nbsp;(<?php echo $lang['txt_joined'];?>: <?php echo $i['profile_create_datetime'];?>, <?php echo $lang['txt_hometown'];?>: <?php echo $i['profile_hometown'];?>)<br />
									<?php echo $lang['txt_comment_datetime'];?>: <?php echo $i['comment_create_datetime'];?><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<?php echo $i['comment_body'];?><br />
								</td>
								<td valign="top" align="right">
									<?php
									if (isset($poll) && !isset($poll['poll_anon'])) {
									?>
									<table cellpadding="2" cellspacing="0" border="0">
										<tr>
											<td valign="top" colspan="2">
												<?php echo $lang['hdr_vote_history'];?><br />
											</td>
										</tr>
										<?php
										if (isset($i['vote'])) {
										foreach($i['vote'] as $key => $r):
										?>
										<tr>
											<td valign="top" class="txt_footer">
												<?php echo $r['answer_create_datetime'];?><br />
											</td>
											<td valign="top" class="txt_footer">
												<?php echo $r['option_body'];?><br />
											</td>
										</tr>
										<?php
										endforeach;
										}
										?>
									</table>
									<?php
									}
									?>
								</td>
						    </tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_comments'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<?php
			if (isset($allow_add_comment)) {
			?>
			<input type="hidden" name="data[comment_body]" value="<?php if (isset($comment['comment_body'])) { echo $comment['comment_body'];}?>" />
						
			<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="20"><br />
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($display) && $display == "preview_comment") {
				?>
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_comment_preview'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $comment['display_comment_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="edit_again" class="formInput" value="<?php echo $lang['sub_edit_again'];?>" />&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_save'];?>" /><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>

				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_comment_help'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name="data[comment_body]" rows="5" cols="70" class="formInput"><?php if(isset($comment['comment_body'])) { echo $comment['comment_body'];}?></textarea><br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="preview" class="formInput" value="<?php echo $lang['sub_preview'];?>">&nbsp;&nbsp;
						<input type="submit" name="insert" class="formInput" value="<?php echo $lang['sub_add'];?>"><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
			<?php
			}
			else {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_add_comment'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_no_comment_allowed'];?><br />
					</td>
				</tr>
			</table>
			<?php
			}
			?>
			</form>
		</td>
	</tr>
</table>
